@@ -25,6 +25,7 @@ import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Spliterator;
 
 import javax.xml.namespace.QName;
 
@@ -33,6 +34,7 @@ import org.apache.logging.log4j.Logger;
 import org.apache.poi.ooxml.POIXMLDocumentPart;
 import org.apache.poi.ooxml.POIXMLException;
 import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
+import org.apache.poi.openxml4j.opc.OPCPackage;
 import org.apache.poi.openxml4j.opc.PackagePart;
 import org.apache.poi.openxml4j.opc.PackagePartName;
 import org.apache.poi.openxml4j.opc.PackageRelationship;
@@ -41,11 +43,10 @@ import org.apache.poi.openxml4j.opc.PackagingURIHelper;
 import org.apache.poi.openxml4j.opc.TargetMode;
 import org.apache.poi.ss.usermodel.ClientAnchor;
 import org.apache.poi.ss.usermodel.Drawing;
-import org.apache.poi.ss.util.CellAddress;
 import org.apache.poi.ss.util.ImageUtils;
 import org.apache.poi.util.Internal;
 import org.apache.poi.util.Units;
-import org.apache.poi.xssf.model.CommentsTable;
+import org.apache.poi.xssf.model.Comments;
 import org.apache.xmlbeans.XmlCursor;
 import org.apache.xmlbeans.XmlException;
 import org.apache.xmlbeans.XmlObject;
@@ -152,9 +153,9 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
             .setSaveSyntheticDocumentElement(new QName(CTDrawing.type.getName().getNamespaceURI(), "wsDr", "xdr"));
 
         PackagePart part = getPackagePart();
-        OutputStream out = part.getOutputStream();
-        drawing.save(out, xmlOptions);
-        out.close();
+        try (OutputStream out = part.getOutputStream()) {
+            drawing.save(out, xmlOptions);
+        }
     }
 
     @Override
@@ -243,9 +244,21 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
     protected RelationPart createChartRelationPart() {
         XSSFWorkbook wb = getSheet().getWorkbook();
         XSSFFactory factory = wb == null ? XSSFFactory.getInstance() : wb.getXssfFactory();
-        int chartNumber = getPackagePart().getPackage().getPartsByContentType(XSSFRelation.CHART.getContentType())
+        OPCPackage pkg = getPackagePart().getPackage();
+        int chartNumber = pkg.getPartsByContentType(XSSFRelation.CHART.getContentType())
             .size() + 1;
 
+        // some broken files have incorrectly named package parts,
+        // so we need to avoid duplicates here by checking and increasing
+        // the part-number
+        try {
+            while (pkg.getPart(PackagingURIHelper.createPartName(XSSFRelation.CHART.getFileName(chartNumber))) != null) {
+                chartNumber++;
+            }
+        } catch (InvalidFormatException e) {
+            throw new IllegalStateException("Failed for " + chartNumber, e);
+        }
+
         return createRelationship(XSSFRelation.CHART, factory, chartNumber, false);
     }
 
@@ -368,32 +381,10 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
      */
     @Override
     public XSSFComment createCellComment(ClientAnchor anchor) {
-        XSSFClientAnchor ca = (XSSFClientAnchor) anchor;
         XSSFSheet sheet = getSheet();
 
-        // create comments and vmlDrawing parts if they don't exist
-        CommentsTable comments = sheet.getCommentsTable(true);
-        XSSFVMLDrawing vml = sheet.getVMLDrawing(true);
-        com.microsoft.schemas.vml.CTShape vmlShape = vml.newCommentShape();
-        if (ca.isSet()) {
-            // convert offsets from emus to pixels since we get a
-            // DrawingML-anchor
-            // but create a VML Drawing
-            int dx1Pixels = ca.getDx1() / Units.EMU_PER_PIXEL;
-            int dy1Pixels = ca.getDy1() / Units.EMU_PER_PIXEL;
-            int dx2Pixels = ca.getDx2() / Units.EMU_PER_PIXEL;
-            int dy2Pixels = ca.getDy2() / Units.EMU_PER_PIXEL;
-            String position = ca.getCol1() + ", " + dx1Pixels + ", " + ca.getRow1() + ", " + dy1Pixels + ", " + ca
-                .getCol2() + ", " + dx2Pixels + ", " + ca.getRow2() + ", " + dy2Pixels;
-            vmlShape.getClientDataArray(0).setAnchorArray(0, position);
-        }
-        CellAddress ref = new CellAddress(ca.getRow1(), ca.getCol1());
-
-        if (comments.findCellComment(ref) != null) {
-            throw new IllegalArgumentException("Multiple cell comments in one cell are not allowed, cell: " + ref);
-        }
-
-        return new XSSFComment(comments, comments.newComment(ref), vmlShape);
+        Comments comments = sheet.getCommentsTable(true);
+        return comments.createNewComment(anchor);
     }
 
     /**
@@ -470,27 +461,27 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
         ole1.setShapeId(shapeId);
         ole1.setId(olePR.getId());
 
-        XmlCursor cur1 = ole1.newCursor();
-        cur1.toEndToken();
-        cur1.beginElement("objectPr", XSSFRelation.NS_SPREADSHEETML);
-        cur1.insertAttributeWithValue("id", PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, imgSheetPR.getId());
-        cur1.insertAttributeWithValue("defaultSize", "0");
-        cur1.beginElement("anchor", XSSFRelation.NS_SPREADSHEETML);
-        cur1.insertAttributeWithValue("moveWithCells", "1");
+        CTTwoCellAnchor ctAnchor;
+        try (XmlCursor cur1 = ole1.newCursor()) {
+            cur1.toEndToken();
+            cur1.beginElement("objectPr", XSSFRelation.NS_SPREADSHEETML);
+            cur1.insertAttributeWithValue("id", PackageRelationshipTypes.CORE_PROPERTIES_ECMA376_NS, imgSheetPR.getId());
+            cur1.insertAttributeWithValue("defaultSize", "0");
+            cur1.beginElement("anchor", XSSFRelation.NS_SPREADSHEETML);
+            cur1.insertAttributeWithValue("moveWithCells", "1");
 
-        CTTwoCellAnchor ctAnchor = createTwoCellAnchor((XSSFClientAnchor) anchor);
+            ctAnchor = createTwoCellAnchor((XSSFClientAnchor) anchor);
 
-        XmlCursor cur2 = ctAnchor.newCursor();
-        cur2.copyXmlContents(cur1);
-        cur2.dispose();
+            try (XmlCursor cur2 = ctAnchor.newCursor()) {
+                cur2.copyXmlContents(cur1);
+            }
 
-        cur1.toParent();
-        cur1.toFirstChild();
-        cur1.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "from"));
-        cur1.toNextSibling();
-        cur1.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "to"));
-
-        cur1.dispose();
+            cur1.toParent();
+            cur1.toFirstChild();
+            cur1.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "from"));
+            cur1.toNextSibling();
+            cur1.setName(new QName(XSSFRelation.NS_SPREADSHEETML, "to"));
+        }
 
         // add a new shape and link OLE & image part
         CTShape ctShape = ctAnchor.addNewSp();
@@ -506,10 +497,10 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
         cNvPr.setId(shapeId);
         cNvPr.setName("Object " + shapeId);
 
-        XmlCursor extCur = cNvPr.getExtLst().getExtArray(0).newCursor();
-        extCur.toFirstChild();
-        extCur.setAttributeText(new QName("spid"), "_x0000_s" + shapeId);
-        extCur.dispose();
+        try (XmlCursor extCur = cNvPr.getExtLst().getExtArray(0).newCursor()) {
+            extCur.toFirstChild();
+            extCur.setAttributeText(new QName("spid"), "_x0000_s" + shapeId);
+        }
 
         XSSFObjectData shape = new XSSFObjectData(this, ctShape);
         shape.anchor = (XSSFClientAnchor) anchor;
@@ -595,13 +586,10 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
      */
     public List<XSSFShape> getShapes() {
         List<XSSFShape> lst = new ArrayList<>();
-        XmlCursor cur = drawing.newCursor();
-        try {
+        try (XmlCursor cur = drawing.newCursor()) {
             if (cur.toFirstChild()) {
                 addShapes(cur, lst);
             }
-        } finally {
-            cur.dispose();
         }
         return lst;
     }
@@ -611,96 +599,83 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
      */
     public List<XSSFShape> getShapes(XSSFShapeGroup groupshape) {
         List<XSSFShape> lst = new ArrayList<>();
-        XmlCursor cur = groupshape.getCTGroupShape().newCursor();
-        try {
+        try (XmlCursor cur = groupshape.getCTGroupShape().newCursor()) {
             addShapes(cur, lst);
-        } finally {
-            cur.dispose();
         }
         return lst;
     }
 
     private void addShapes(XmlCursor cur, List<XSSFShape> lst) {
-        try {
-            do {
-                cur.push();
-                if (cur.toFirstChild()) {
-                    do {
-                        XmlObject obj = cur.getObject();
+        do {
+            cur.push();
+            if (cur.toFirstChild()) {
+                do {
+                    XmlObject obj = cur.getObject();
 
-                        XSSFShape shape;
-                        if (obj instanceof CTMarker) {
-                            // ignore anchor elements
-                            continue;
-                        } else if (obj instanceof CTPicture) {
-                            shape = new XSSFPicture(this, (CTPicture) obj);
-                        } else if (obj instanceof CTConnector) {
-                            shape = new XSSFConnector(this, (CTConnector) obj);
-                        } else if (obj instanceof CTShape) {
-                            shape = hasOleLink(obj) ? new XSSFObjectData(this, (CTShape) obj)
-                                : new XSSFSimpleShape(this, (CTShape) obj);
-                        } else if (obj instanceof CTGraphicalObjectFrame) {
-                            shape = new XSSFGraphicFrame(this, (CTGraphicalObjectFrame) obj);
-                        } else if (obj instanceof CTGroupShape) {
-                            shape = new XSSFShapeGroup(this, (CTGroupShape) obj);
-                        } else if (obj instanceof XmlAnyTypeImpl) {
-                            LOG.atWarn().log("trying to parse AlternateContent, this unlinks the returned Shapes from the underlying xml content, so those shapes can't be used to modify the drawing, i.e. modifications will be ignored!");
+                    XSSFShape shape;
+                    if (obj instanceof CTMarker) {
+                        // ignore anchor elements
+                        continue;
+                    } else if (obj instanceof CTPicture) {
+                        shape = new XSSFPicture(this, (CTPicture) obj);
+                    } else if (obj instanceof CTConnector) {
+                        shape = new XSSFConnector(this, (CTConnector) obj);
+                    } else if (obj instanceof CTShape) {
+                        shape = hasOleLink(obj) ? new XSSFObjectData(this, (CTShape) obj)
+                            : new XSSFSimpleShape(this, (CTShape) obj);
+                    } else if (obj instanceof CTGraphicalObjectFrame) {
+                        shape = new XSSFGraphicFrame(this, (CTGraphicalObjectFrame) obj);
+                    } else if (obj instanceof CTGroupShape) {
+                        shape = new XSSFShapeGroup(this, (CTGroupShape) obj);
+                    } else if (obj instanceof XmlAnyTypeImpl) {
+                        LOG.atWarn().log("trying to parse AlternateContent, this unlinks the returned Shapes from the underlying xml content, so those shapes can't be used to modify the drawing, i.e. modifications will be ignored!");
 
-                            // XmlAnyTypeImpl is returned for AlternateContent
-                            // parts, which might contain a CTDrawing
-                            cur.push();
-                            cur.toFirstChild();
-                            XmlCursor cur2 = null;
-                            try {
-                                // need to parse AlternateContent again,
-                                // otherwise the child elements aren't typed,
-                                // but also XmlAnyTypes
-                                CTDrawing alterWS = CTDrawing.Factory.parse(cur.newXMLStreamReader());
-                                cur2 = alterWS.newCursor();
+                        // XmlAnyTypeImpl is returned for AlternateContent
+                        // parts, which might contain a CTDrawing
+                        cur.push();
+                        cur.toFirstChild();
+                        try {
+                            // need to parse AlternateContent again,
+                            // otherwise the child elements aren't typed,
+                            // but also XmlAnyTypes
+                            CTDrawing alterWS = CTDrawing.Factory.parse(cur.newXMLStreamReader());
+                            try (XmlCursor cur2 = alterWS.newCursor()) {
                                 if (cur2.toFirstChild()) {
                                     addShapes(cur2, lst);
                                 }
-                            } catch (XmlException e) {
-                                LOG.atWarn().withThrowable(e).log("unable to parse CTDrawing in alternate content.");
-                            } finally {
-                                if (cur2 != null) {
-                                    cur2.dispose();
-                                }
-                                cur.pop();
                             }
-                            continue;
-                        } else {
-                            // ignore anything else
-                            continue;
+                        } catch (XmlException e) {
+                            LOG.atWarn().withThrowable(e).log("unable to parse CTDrawing in alternate content.");
+                        } finally {
+                            cur.pop();
                         }
+                        continue;
+                    } else {
+                        // ignore anything else
+                        continue;
+                    }
 
-                        assert (shape != null);
-                        shape.anchor = getAnchorFromParent(obj);
-                        lst.add(shape);
+                    assert (shape != null);
+                    shape.anchor = getAnchorFromParent(obj);
+                    lst.add(shape);
 
-                    } while (cur.toNextSibling());
-                }
-                cur.pop();
-            } while (cur.toNextSibling());
-        } finally {
-            cur.dispose();
-        }
+                } while (cur.toNextSibling());
+            }
+            cur.pop();
+        } while (cur.toNextSibling());
     }
 
     private boolean hasOleLink(XmlObject shape) {
         QName uriName = new QName(null, "uri");
         String xquery = "declare namespace a='" + XSSFRelation.NS_DRAWINGML + "' .//a:extLst/a:ext";
-        XmlCursor cur = shape.newCursor();
-        cur.selectPath(xquery);
-        try {
+        try (XmlCursor cur = shape.newCursor()) {
+            cur.selectPath(xquery);
             while (cur.toNextSelection()) {
                 String uri = cur.getAttributeText(uriName);
                 if ("{63B3BB69-23CF-44E3-9099-C40C66FF867C}".equals(uri)) {
                     return true;
                 }
             }
-        } finally {
-            cur.dispose();
         }
         return false;
     }
@@ -709,11 +684,11 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
         XSSFAnchor anchor = null;
 
         XmlObject parentXbean = null;
-        XmlCursor cursor = obj.newCursor();
-        if (cursor.toParent()) {
-            parentXbean = cursor.getObject();
+        try (XmlCursor cursor = obj.newCursor()) {
+            if (cursor.toParent()) {
+                parentXbean = cursor.getObject();
+            }
         }
-        cursor.dispose();
         if (parentXbean != null) {
             if (parentXbean instanceof CTTwoCellAnchor) {
                 CTTwoCellAnchor ct = (CTTwoCellAnchor) parentXbean;
@@ -734,6 +709,14 @@ public final class XSSFDrawing extends POIXMLDocumentPart implements Drawing<XSS
         return getShapes().iterator();
     }
 
+    /**
+     * @since POI 5.2.0
+     */
+    @Override
+    public Spliterator<XSSFShape> spliterator() {
+        return getShapes().spliterator();
+    }
+
     /**
      * @return the sheet associated with the drawing
      */
