@@ -17,11 +17,15 @@
 
 package org.apache.poi.xssf.usermodel;
 
+import org.apache.commons.compress.archivers.zip.ZipArchiveEntry;
+import org.apache.commons.compress.archivers.zip.ZipArchiveInputStream;
+import org.apache.commons.compress.archivers.zip.ZipArchiveOutputStream;
 import org.apache.commons.io.output.NullOutputStream;
 import org.apache.commons.io.output.UnsynchronizedByteArrayOutputStream;
 import org.apache.poi.POIDataSamples;
 import org.apache.poi.hssf.HSSFTestDataSamples;
 import org.apache.poi.ooxml.POIXMLProperties;
+import org.apache.poi.ooxml.TrackingInputStream;
 import org.apache.poi.openxml4j.exceptions.InvalidFormatException;
 import org.apache.poi.openxml4j.opc.ContentTypes;
 import org.apache.poi.openxml4j.opc.OPCPackage;
@@ -61,6 +65,8 @@ import org.apache.poi.xddf.usermodel.chart.XDDFBarChartData;
 import org.apache.poi.xddf.usermodel.chart.XDDFChartData;
 import org.apache.poi.xssf.XSSFITestDataProvider;
 import org.apache.poi.xssf.model.StylesTable;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTCalcPr;
 import org.openxmlformats.schemas.spreadsheetml.x2006.main.CTExternalLink;
@@ -75,13 +81,17 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
+import java.io.InputStream;
 import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
 import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Locale;
 import java.util.zip.CRC32;
 
 import static org.apache.poi.hssf.HSSFTestDataSamples.openSampleFileStream;
+import static org.apache.poi.xssf.XSSFTestDataSamples.getSampleFile;
 import static org.apache.poi.xssf.XSSFTestDataSamples.openSampleWorkbook;
 import static org.apache.poi.xssf.XSSFTestDataSamples.writeOut;
 import static org.apache.poi.xssf.XSSFTestDataSamples.writeOutAndReadBack;
@@ -100,6 +110,16 @@ public final class TestXSSFWorkbook extends BaseTestXWorkbook {
         super(XSSFITestDataProvider.instance);
     }
 
+    @BeforeAll
+    static void setUp() {
+        LocaleUtil.setUserLocale(Locale.US);
+    }
+
+    @AfterAll
+    static void tearDown() {
+        LocaleUtil.setUserLocale(null);
+    }
+
     /**
      * Tests that we can save, and then re-load a new document
      */
@@ -1427,6 +1447,68 @@ public final class TestXSSFWorkbook extends BaseTestXWorkbook {
         }
     }
 
+    @Test
+    void testWorkbookCloseClosesInputStream() throws Exception {
+        try (TrackingInputStream stream = new TrackingInputStream(
+                HSSFTestDataSamples.openSampleFileStream("github-321.xlsx"))) {
+            try (XSSFWorkbook wb = new XSSFWorkbook(stream)) {
+                XSSFSheet xssfSheet = wb.getSheetAt(0);
+                assertNotNull(xssfSheet);
+            }
+            assertTrue(stream.isClosed(), "stream should be closed by XSSFWorkbook");
+        }
+    }
+
+    @Test
+    void testWorkbookCloseCanBeStoppedFromClosingInputStream() throws Exception {
+        try (TrackingInputStream stream = new TrackingInputStream(
+                HSSFTestDataSamples.openSampleFileStream("github-321.xlsx"))) {
+            // uses new constructor, available since POI 5.2.5
+            try (XSSFWorkbook wb = new XSSFWorkbook(stream, false)) {
+                XSSFSheet xssfSheet = wb.getSheetAt(0);
+                assertNotNull(xssfSheet);
+            }
+            assertFalse(stream.isClosed(), "stream should not be closed by XSSFWorkbook");
+        }
+    }
+
+    @Test
+    void readFromZipStream() throws IOException {
+        File tempFile = TempFile.createTempFile("poitest", ".zip");
+        try {
+            try (ZipArchiveOutputStream zos = new ZipArchiveOutputStream(tempFile)) {
+                File f1 = getSampleFile("github-321.xlsx");
+                File f2 = getSampleFile("48495.xlsx");
+                ZipArchiveEntry e1 = zos.createArchiveEntry(f1, "github-321.xlsx");
+                zos.putArchiveEntry(e1);
+                try (InputStream s = Files.newInputStream(f1.toPath())) {
+                    IOUtils.copy(s, zos);
+                }
+                zos.closeArchiveEntry();
+                ZipArchiveEntry e2 = zos.createArchiveEntry(f2, "48495.xlsx");
+                zos.putArchiveEntry(e2);
+                try (InputStream s = Files.newInputStream(f2.toPath())) {
+                    IOUtils.copy(s, zos);
+                }
+                zos.closeArchiveEntry();
+                zos.finish();
+            }
+            int count = 0;
+            try (ZipArchiveInputStream zis = new ZipArchiveInputStream(Files.newInputStream(tempFile.toPath()))) {
+                ZipArchiveEntry entry;
+                while ((entry = zis.getNextZipEntry()) != null) {
+                    // Since POI 5.2.5, you can stop XSSFWorkbook closing the InputStream by using this new constructor
+                    XSSFWorkbook wb = new XSSFWorkbook(zis, false);
+                    assertNotNull(wb);
+                    count++;
+                }
+            }
+            assertEquals(2, count);
+        } finally {
+            assertTrue(tempFile.delete());
+        }
+    }
+
     private static void expectFormattedContent(Cell cell, String value) {
         assertEquals(value, new DataFormatter().formatCellValue(cell),
                 "Cell " + ref(cell) + " has wrong formatted content.");
