@@ -23,6 +23,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
+import java.util.Spliterator;
 import java.util.function.Supplier;
 import java.util.stream.Collectors;
 
@@ -41,7 +42,7 @@ import static org.apache.logging.log4j.util.Unbox.box;
 
 /**
  * Unicode String - just standard fields that are in several records.
- * It is considered more desirable then repeating it in all of them.<p>
+ * It is considered more desirable than repeating it in all of them.<p>
  * This is often called a XLUnicodeRichExtendedString in MS documentation.
  */
 public class UnicodeString implements Comparable<UnicodeString>, Duplicatable, GenericRecord {
@@ -73,7 +74,7 @@ public class UnicodeString implements Comparable<UnicodeString>, Duplicatable, G
 
     /**
      * construct a unicode string record and fill its fields, ID is ignored
-     * @param in the RecordInputstream to read the record from
+     * @param in the RecordInputStream to read the record from
      */
     public UnicodeString(RecordInputStream in) {
         field_1_charCount   = in.readShort();
@@ -114,8 +115,8 @@ public class UnicodeString implements Comparable<UnicodeString>, Duplicatable, G
     }
 
     /**
-     * Our handling of equals is inconsistent with compareTo.  The trouble is because we don't truely understand
-     * rich text fields yet it's difficult to make a sound comparison.
+     * Our handling of equals is inconsistent with compareTo.  The trouble is because we don't truly understand
+     * rich text fields, yet it's difficult to make a sound comparison.
      *
      * @param o     The object to compare.
      * @return      true if the object is actually equal.
@@ -127,7 +128,7 @@ public class UnicodeString implements Comparable<UnicodeString>, Duplicatable, G
         }
         UnicodeString other = (UnicodeString) o;
 
-        //OK lets do this in stages to return a quickly, first check the actual string
+        //OK lets do this in stages to return quickly, first check the actual string
         if (field_1_charCount != other.field_1_charCount
                 || field_2_optionflags != other.field_2_optionflags
                 || !field_3_string.equals(other.field_3_string)) {
@@ -324,9 +325,19 @@ public class UnicodeString implements Comparable<UnicodeString>, Duplicatable, G
       return null;
     }
 
+    /**
+     * @since POI 5.2.0
+     */
+    public Spliterator<FormatRun> formatSpliterator() {
+        if (field_4_format_runs != null) {
+            return field_4_format_runs.spliterator();
+        }
+        return null;
+    }
+
     public void removeFormatRun(FormatRun r) {
       field_4_format_runs.remove(r);
-      if (field_4_format_runs.size() == 0) {
+      if (field_4_format_runs.isEmpty()) {
         field_4_format_runs = null;
         field_2_optionflags = richText.clearByte(field_2_optionflags);
       }
