@@ -17,6 +17,8 @@
 
 package org.apache.poi.sl.draw;
 
+import static org.apache.logging.log4j.util.Unbox.box;
+
 import java.awt.Dimension;
 import java.awt.Font;
 import java.awt.Graphics2D;
@@ -30,8 +32,10 @@ import java.io.InvalidObjectException;
 import java.text.AttributedCharacterIterator;
 import java.text.AttributedCharacterIterator.Attribute;
 import java.text.AttributedString;
+import java.time.LocalDateTime;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Calendar;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Locale;
@@ -43,12 +47,13 @@ import org.apache.poi.common.usermodel.fonts.FontGroup;
 import org.apache.poi.common.usermodel.fonts.FontGroup.FontGroupRange;
 import org.apache.poi.common.usermodel.fonts.FontInfo;
 import org.apache.poi.sl.usermodel.AutoNumberingScheme;
+import org.apache.poi.sl.usermodel.HighlightColorSupport;
 import org.apache.poi.sl.usermodel.Hyperlink;
 import org.apache.poi.sl.usermodel.Insets2D;
 import org.apache.poi.sl.usermodel.PaintStyle;
 import org.apache.poi.sl.usermodel.PlaceableShape;
-import org.apache.poi.sl.usermodel.ShapeContainer;
-import org.apache.poi.sl.usermodel.Sheet;
+import org.apache.poi.sl.usermodel.PlaceholderDetails;
+import org.apache.poi.sl.usermodel.SimpleShape;
 import org.apache.poi.sl.usermodel.Slide;
 import org.apache.poi.sl.usermodel.TextParagraph;
 import org.apache.poi.sl.usermodel.TextParagraph.BulletStyle;
@@ -59,9 +64,9 @@ import org.apache.poi.sl.usermodel.TextShape;
 import org.apache.poi.sl.usermodel.TextShape.TextDirection;
 import org.apache.poi.util.Internal;
 import org.apache.poi.util.LocaleUtil;
+import org.apache.poi.util.StringUtil;
 import org.apache.poi.util.Units;
-
-import static org.apache.logging.log4j.util.Unbox.box;
+import org.w3c.dom.Text;
 
 public class DrawTextParagraph implements Drawable {
     private static final Logger LOG = LogManager.getLogger(DrawTextParagraph.class);
@@ -240,7 +245,7 @@ public class DrawTextParagraph implements Drawable {
     }
 
     public boolean isEmptyParagraph() {
-        return (lines.isEmpty() || rawText.trim().isEmpty());
+        return (lines.isEmpty() || StringUtil.isBlank(rawText));
     }
 
     @Override
@@ -365,9 +370,9 @@ public class DrawTextParagraph implements Drawable {
             buSz = 100d;
         }
         if (buSz > 0) {
-            fontSize *= buSz* 0.01;
+            fontSize *= (float) (buSz * 0.01);
         } else {
-            fontSize = (float)-buSz;
+            fontSize = (float) -buSz;
         }
 
         String buFontStr = bulletStyle.getBulletFont();
@@ -397,11 +402,31 @@ public class DrawTextParagraph implements Drawable {
     }
 
     protected String getRenderableText(Graphics2D graphics, TextRun tr) {
-        if (tr.getFieldType() == FieldType.SLIDE_NUMBER) {
-            Slide<?,?> slide = (Slide<?,?>)graphics.getRenderingHint(Drawable.CURRENT_SLIDE);
-            return (slide == null) ? "" : Integer.toString(slide.getSlideNumber());
+        FieldType ft = tr.getFieldType();
+        if (ft == null) {
+            return getRenderableText(tr);
         }
-        return getRenderableText(tr);
+        if (tr.getRawText() != null && !tr.getRawText().isEmpty()) {
+            switch (ft) {
+                case SLIDE_NUMBER: {
+                    Slide<?, ?> slide = (Slide<?, ?>) graphics.getRenderingHint(Drawable.CURRENT_SLIDE);
+                    return (slide == null) ? "" : Integer.toString(slide.getSlideNumber());
+                }
+                case DATE_TIME: {
+                    PlaceholderDetails pd = ((SimpleShape<?, ?>) this.getParagraphShape()).getPlaceholderDetails();
+                    // refresh internal members
+                    pd.getPlaceholder();
+                    String uda = pd.getUserDate();
+                    if (uda != null) {
+                        return uda;
+                    }
+                    Calendar cal = LocaleUtil.getLocaleCalendar();
+                    LocalDateTime now = LocalDateTime.ofInstant(cal.toInstant(), cal.getTimeZone().toZoneId());
+                    return now.format(pd.getDateFormat());
+                }
+            }
+        }
+        return "";
     }
 
     @Internal
@@ -550,30 +575,8 @@ public class DrawTextParagraph implements Drawable {
     /**
      * Helper method for paint style relative to bounds, e.g. gradient paint
      */
-    @SuppressWarnings("rawtypes")
     private PlaceableShape<?,?> getParagraphShape() {
-        return new PlaceableShape(){
-            @Override
-            public ShapeContainer<?,?> getParent() { return null; }
-            @Override
-            public Rectangle2D getAnchor() { return paragraph.getParentShape().getAnchor(); }
-            @Override
-            public void setAnchor(Rectangle2D anchor) {}
-            @Override
-            public double getRotation() { return 0; }
-            @Override
-            public void setRotation(double theta) {}
-            @Override
-            public void setFlipHorizontal(boolean flip) {}
-            @Override
-            public void setFlipVertical(boolean flip) {}
-            @Override
-            public boolean getFlipHorizontal() { return false; }
-            @Override
-            public boolean getFlipVertical() { return false; }
-            @Override
-            public Sheet<?,?> getSheet() { return paragraph.getParentShape().getSheet(); }
-        };
+        return paragraph.getParentShape();
     }
 
     protected List<AttributedStringData> getAttributedString(Graphics2D graphics, StringBuilder text) {
@@ -609,6 +612,15 @@ public class DrawTextParagraph implements Drawable {
 
             att.put(TextAttribute.FOREGROUND, fgPaint);
 
+            if (run instanceof HighlightColorSupport) {
+                // Highlight color is only supported in XSLF (PPTX) text runs.
+                final PaintStyle highlightPaintStyle = ((HighlightColorSupport)run).getHighlightColor();
+                if (highlightPaintStyle != null) {
+                    final Paint bgPaint = dp.getPaint(graphics, highlightPaintStyle);
+                    att.put(TextAttribute.BACKGROUND, bgPaint);
+                }
+            }
+
             Double fontSz = run.getFontSize();
             if (fontSz == null) {
                 fontSz = paragraph.getDefaultFontSize();
@@ -671,9 +683,11 @@ public class DrawTextParagraph implements Drawable {
     }
 
     /**
-     * Processing the glyphs is done in two steps.
-     * <li>determine the font group - a text run can have different font groups. Depending on the chars,
-     * the correct font group needs to be used
+     * Processing the glyphs is done in two steps:
+     * <ul>
+     * <li>1. determine the font group - a text run can have different font groups.
+     * <li>2. Depending on the chars, the correct font group needs to be used
+     * </ul>
      *
      * @see <a href="https://blogs.msdn.microsoft.com/officeinteroperability/2013/04/22/office-open-xml-themes-schemes-and-fonts/">Office Open XML Themes, Schemes, and Fonts</a>
      */
