@@ -80,6 +80,7 @@ import org.apache.poi.ss.util.AreaReference;
 import org.apache.poi.ss.util.CellReference;
 import org.apache.poi.ss.util.CellReference.NameType;
 import org.apache.poi.util.Internal;
+import org.apache.poi.util.StringUtil;
 
 /**
  * This class parses a formula string into a List of tokens in RPN order.
@@ -97,6 +98,7 @@ import org.apache.poi.util.Internal;
 @Internal
 public final class FormulaParser {
     private static final Logger LOGGER = LogManager.getLogger(FormulaParser.class);
+
     private final String _formulaString;
     private final int _formulaLength;
     /** points at the next character to be read (after the {@link #look} codepoint) */
@@ -212,10 +214,10 @@ public final class FormulaParser {
     }
 
     /** Read New Character From Input Stream */
-    private void GetChar() {
+    private void nextChar() {
         // The intersection operator is a space.  We track whether the run of
         // whitespace preceding "look" counts as an intersection operator.
-        if (IsWhite(look)) {
+        if (isWhite(look)) {
             if (look == ' ') {
                 _inIntersection = true;
             }
@@ -226,7 +228,7 @@ public final class FormulaParser {
 
         // Check to see if we've walked off the end of the string.
         if (_pointer > _formulaLength) {
-            throw new RuntimeException("Parsed past the end of the formula, pos: " + _pointer +
+            throw new IllegalStateException("Parsed past the end of the formula, pos: " + _pointer +
                     ", length: " + _formulaLength + ", formula: " + _formulaString);
         }
         if (_pointer < _formulaLength) {
@@ -254,7 +256,7 @@ public final class FormulaParser {
     private RuntimeException expected(String s) {
         String msg;
 
-        if (look == '=' && _formulaString.substring(0, _pointer-1).trim().length() < 1) {
+        if (look == '=' && StringUtil.isBlank(_formulaString.substring(0, _pointer-1))) {
             msg = "The specified formula '" + _formulaString
                 + "' starts with an equals sign which is not allowed.";
         } else {
@@ -273,24 +275,24 @@ public final class FormulaParser {
     }
 
     /** Recognize an Alpha Character */
-    private static boolean IsAlpha(int c) {
+    private static boolean isAlpha(int c) {
         return Character.isLetter(c) || c == '$' || c=='_';
     }
 
     /** Recognize a Decimal Digit */
-    private static boolean IsDigit(int c) {
+    private static boolean isDigit(int c) {
         return Character.isDigit(c);
     }
 
     /** Recognize White Space */
-    private static boolean IsWhite(int c) {
+    private static boolean isWhite(int c) {
         return  c ==' ' || c== TAB || c == CR || c == LF;
     }
 
     /** Skip Over Leading White Space */
-    private void SkipWhite() {
-        while (IsWhite(look)) {
-            GetChar();
+    private void skipWhite() {
+        while (isWhite(look)) {
+            nextChar();
         }
     }
 
@@ -299,7 +301,7 @@ public final class FormulaParser {
      *  unchecked exception. This method does <b>not</b> consume whitespace (before or after the
      *  matched character).
      */
-    private void Match(int x) {
+    private void match(int x) {
         if (look != x) {
             throw expected(new StringBuilder()
                     .append("'")
@@ -307,16 +309,16 @@ public final class FormulaParser {
                     .append("'")
                     .toString());
         }
-        GetChar();
+        nextChar();
     }
 
     /** Get a Number */
-    private String GetNum() {
+    private String nextNum() {
         StringBuilder value = new StringBuilder();
 
-        while (IsDigit(this.look)){
+        while (isDigit(this.look)){
             value.appendCodePoint(this.look);
-            GetChar();
+            nextChar();
         }
         return value.length() == 0 ? null : value.toString();
     }
@@ -326,7 +328,7 @@ public final class FormulaParser {
         boolean hasRange = false;
         while (look == ':') {
             int pos = _pointer;
-            GetChar();
+            nextChar();
             ParseNode nextPart = parseRangeable();
             // Note - no range simplification here. An expr like "A1:B2:C3:D4:E5" should be
             // grouped into area ref pairs like: "(A1:B2):(C3:D4):E5"
@@ -413,7 +415,9 @@ public final class FormulaParser {
         if (tkn instanceof AbstractFunctionPtg) {
             AbstractFunctionPtg afp = (AbstractFunctionPtg) tkn;
             byte returnClass = afp.getDefaultOperandClass();
-            return Ptg.CLASS_REF == returnClass;
+            //CLASS_VALUE was added as valid to support example 6 in
+            //https://support.microsoft.com/en-us/office/xlookup-function-b7fd680e-6d10-43e6-84f9-88eae8bf5929
+            return Ptg.CLASS_REF == returnClass || Ptg.CLASS_VALUE == returnClass;
         }
         if (tkn instanceof ValueOperatorPtg) {
             return false;
@@ -460,14 +464,14 @@ public final class FormulaParser {
      *
      */
     private ParseNode parseRangeable() {
-        SkipWhite();
+        skipWhite();
         int savePointer = _pointer;
-        SheetIdentifier sheetIden = parseSheetName();
+        SheetIdentifier sheetIden = parseSheetName(false);
 
         if (sheetIden == null) {
             resetPointer(savePointer);
         } else {
-            SkipWhite();
+            skipWhite();
             savePointer = _pointer;
         }
 
@@ -493,15 +497,15 @@ public final class FormulaParser {
             }
             return parseNonRange(savePointer);
         }
-        boolean whiteAfterPart1 = IsWhite(look);
+        boolean whiteAfterPart1 = isWhite(look);
         if (whiteAfterPart1) {
-            SkipWhite();
+            skipWhite();
         }
 
         if (look == ':') {
             int colonPos = _pointer;
-            GetChar();
-            SkipWhite();
+            nextChar();
+            skipWhite();
             SimpleRangePart part2 = parseSimpleRangePart();
             if (part2 != null && !part1.isCompatibleForArea(part2)) {
                 // second part is not compatible with an area ref e.g. S!A1:S!B2
@@ -525,15 +529,15 @@ public final class FormulaParser {
         }
 
         if (look == '.') {
-            GetChar();
+            nextChar();
             int dotCount = 1;
             while (look =='.') {
                 dotCount ++;
-                GetChar();
+                nextChar();
             }
-            boolean whiteBeforePart2 = IsWhite(look);
+            boolean whiteBeforePart2 = isWhite(look);
 
-            SkipWhite();
+            skipWhite();
             SimpleRangePart part2 = parseSimpleRangePart();
             String part1And2 = _formulaString.substring(savePointer-1, _pointer-1);
             if (part2 == null) {
@@ -591,6 +595,7 @@ public final class FormulaParser {
      * Parses a structured reference, returns it as area reference.
      * Examples:
      * <pre>
+     * Table1[]
      * Table1[col]
      * Table1[[#Totals],[col]]
      * Table1[#Totals]
@@ -631,7 +636,30 @@ public final class FormulaParser {
         // Do NOT return before done reading all the structured reference tokens from the input stream.
         // Throwing exceptions is okay.
         int savePtr0 = _pointer;
-        GetChar();
+        nextChar();
+
+        // Special case: Table1[] is equivalent to Table1[#Data]
+        if (look == ']') {
+
+            // Consume the ']' character
+            nextChar();
+
+            // Skip header and total rows if available
+            int actualStartRow = startRow;
+            if (tbl.getHeaderRowCount() > 0) {
+                actualStartRow = startRow + 1;
+            }
+            int actualEndRow = endRow;
+            if (tbl.getTotalsRowCount() > 0) {
+                actualEndRow = endRow - 1;
+            }
+
+            final CellReference topLeft = new CellReference(actualStartRow, startCol);
+            final CellReference bottomRight = new CellReference(actualEndRow, endCol);
+            final SheetIdentifier sheetIden = new SheetIdentifier( null, new NameIdentifier(sheetName, true));
+            final Ptg ptg = _book.get3DReferencePtg(new AreaReference(topLeft, bottomRight, _ssVersion), sheetIden);
+            return new ParseNode(ptg);
+        }
 
         boolean isTotalsSpec = false;
         boolean isThisRowSpec = false;
@@ -667,23 +695,22 @@ public final class FormulaParser {
             }
             nSpecQuantifiers++;
             if (look == ','){
-                GetChar();
+                nextChar();
             } else {
                 break;
             }
         }
         boolean isThisRow = false;
-        SkipWhite();
+        skipWhite();
         if (look == '@') {
             isThisRow = true;
-            GetChar();
+            nextChar();
         }
         // parse column quantifier
-        String startColumnName;
         String endColumnName = null;
         int nColQuantifiers = 0;
         int savePtr1 = _pointer;
-        startColumnName = parseAsColumnQuantifier();
+        String startColumnName = parseAsColumnQuantifier();
         if (startColumnName == null) {
             resetPointer(savePtr1);
         } else {
@@ -691,7 +718,7 @@ public final class FormulaParser {
             if (look == ','){
                 throw new FormulaParseException("The formula "+ _formulaString + " is illegal: you should not use ',' with column quantifiers");
             } else if (look == ':') {
-                GetChar();
+                nextChar();
                 endColumnName = parseAsColumnQuantifier();
                 nColQuantifiers++;
                 if (endColumnName == null) {
@@ -735,7 +762,7 @@ public final class FormulaParser {
                 }
             }
         } else {
-            Match(']');
+            match(']');
         }
         // Done reading from input stream
         // Ok to return now
@@ -797,7 +824,7 @@ public final class FormulaParser {
 
         if (nColQuantifiers == 2) {
             if (startColumnName == null || endColumnName == null) {
-                throw new IllegalStateException("Fatal error");
+                throw new IllegalStateException("Cannot parse column: " + startColumnName + " and " + endColumnName + " with formula " + _formulaString);
             }
             int startIdx = tbl.findColumnIndex(startColumnName);
             int endIdx = tbl.findColumnIndex(endColumnName);
@@ -809,7 +836,7 @@ public final class FormulaParser {
 
         } else if (nColQuantifiers == 1 && !isThisRow) {
             if (startColumnName == null) {
-                throw new IllegalStateException("Fatal error");
+                throw new IllegalStateException("Cannot parse column: " + startColumnName + " with formula " + _formulaString);
             }
             int idx = tbl.findColumnIndex(startColumnName);
             if (idx == -1) {
@@ -833,19 +860,19 @@ public final class FormulaParser {
         if ( look != '[') {
             return null;
         }
-        GetChar();
+        nextChar();
         if (look == '#') {
             return null;
         }
         if (look == '@') {
-            GetChar();
+            nextChar();
         }
         StringBuilder name = new StringBuilder();
         while (look!=']') {
            name.appendCodePoint(look);
-           GetChar();
+           nextChar();
         }
-        Match(']');
+        match(']');
         return name.toString();
     }
     /**
@@ -856,16 +883,16 @@ public final class FormulaParser {
         if ( look != '[') {
             return null;
         }
-        GetChar();
+        nextChar();
         if( look != '#') {
             return null;
         }
-        GetChar();
+        nextChar();
         String name = parseAsName();
         if ( name.equals("This")) {
             name = name + ' ' + parseAsName();
         }
-        Match(']');
+        match(']');
         return name;
     }
 
@@ -931,9 +958,9 @@ public final class FormulaParser {
         }
         while (isValidDefinedNameChar(look)) {
             sb.appendCodePoint(look);
-            GetChar();
+            nextChar();
         }
-        SkipWhite();
+        skipWhite();
 
         return sb.toString();
     }
@@ -1105,7 +1132,7 @@ public final class FormulaParser {
 
         public CellReference getCellReference() {
             if (_type != Type.CELL) {
-                throw new IllegalStateException("Not applicable to this type");
+                throw new IllegalStateException("Not applicable to this reference-type, expected CELL, but had " + _type);
             }
             return new CellReference(_rep);
         }
@@ -1139,12 +1166,12 @@ public final class FormulaParser {
 
     private String getBookName() {
         StringBuilder sb = new StringBuilder();
-        GetChar();
+        nextChar();
         while (look != ']') {
             sb.appendCodePoint(look);
-            GetChar();
+            nextChar();
         }
-        GetChar();
+        nextChar();
         return sb.toString();
     }
 
@@ -1152,7 +1179,7 @@ public final class FormulaParser {
      * Note - caller should reset {@link #_pointer} upon {@code null} result
      * @return The sheet name as an identifier {@code null} if '!' is not found in the right place
      */
-    private SheetIdentifier parseSheetName() {
+    private SheetIdentifier parseSheetName(boolean isSndPartOfQuotedRange) {
         String bookName;
         if (look == '[') {
             bookName = getBookName();
@@ -1160,8 +1187,10 @@ public final class FormulaParser {
             bookName = null;
         }
 
-        if (look == '\'') {
-            Match('\'');
+        if (look == '\'' || isSndPartOfQuotedRange) {
+            if (!isSndPartOfQuotedRange) {
+                match('\'');
+            }
 
             if (look == '[')
                 bookName = getBookName();
@@ -1170,24 +1199,31 @@ public final class FormulaParser {
             boolean done = look == '\'';
             while(!done) {
                 sb.appendCodePoint(look);
-                GetChar();
-                if(look == '\'')
-                {
-                    Match('\'');
-                    done = look != '\'';
+                nextChar();
+                switch (look){
+                    case '\'' : {
+                        nextChar();
+                        if (look == '\''){
+                            // Any single quotes which were already present in the sheet name will be converted to double single quotes ('')
+                            // so switch back to single quote
+                            break;
+                        }
+                    }
+                    case ':':
+                        done = true;
                 }
             }
 
             NameIdentifier iden = new NameIdentifier(sb.toString(), true);
             // quoted identifier - can't concatenate anything more
-            SkipWhite();
+            skipWhite();
             if (look == '!') {
-                GetChar();
+                nextChar();
                 return new SheetIdentifier(bookName, iden);
             }
             // See if it's a multi-sheet range, eg Sheet1:Sheet3!A1
             if (look == ':') {
-                return parseSheetRange(bookName, iden);
+                return parseSheetRange(bookName, iden, true);
             }
             return null;
         }
@@ -1198,23 +1234,26 @@ public final class FormulaParser {
             // can concatenate idens with dots
             while (isUnquotedSheetNameChar(look)) {
                 sb.appendCodePoint(look);
-                GetChar();
+                nextChar();
+            }
+            if (look == '\'') {
+                nextChar();
             }
             NameIdentifier iden = new NameIdentifier(sb.toString(), false);
-            SkipWhite();
+            skipWhite();
             if (look == '!') {
-                GetChar();
+                nextChar();
                 return new SheetIdentifier(bookName, iden);
             }
             // See if it's a multi-sheet range, eg Sheet1:Sheet3!A1
             if (look == ':') {
-                return parseSheetRange(bookName, iden);
+                return parseSheetRange(bookName, iden, false);
             }
             return null;
         }
         if (look == '!' && bookName != null) {
             // Raw book reference, without a sheet
-            GetChar();
+            nextChar();
             return new SheetIdentifier(bookName, null);
         }
         return null;
@@ -1224,9 +1263,9 @@ public final class FormulaParser {
      * If we have something that looks like [book]Sheet1: or
      *  Sheet1, see if it's actually a range eg Sheet1:Sheet2!
      */
-    private SheetIdentifier parseSheetRange(String bookname, NameIdentifier sheet1Name) {
-        GetChar();
-        SheetIdentifier sheet2 = parseSheetName();
+    private SheetIdentifier parseSheetRange(String bookname, NameIdentifier sheet1Name, boolean isSndPartOfQuotedRange) {
+        nextChar();
+        SheetIdentifier sheet2 = parseSheetName(isSndPartOfQuotedRange);
         if (sheet2 != null) {
            return new SheetRangeIdentifier(bookname, sheet1Name, sheet2.getSheetIdentifier());
         }
@@ -1249,6 +1288,7 @@ public final class FormulaParser {
         switch(ch) {
             case '.': // dot is OK
             case '_': // underscore is OK
+            case ' ': // space is OK
                 return true;
         }
         return false;
@@ -1273,7 +1313,7 @@ public final class FormulaParser {
             if(isFunc){
                 int savePointer = _pointer;
                 resetPointer(_pointer + str.length());
-                SkipWhite();
+                skipWhite();
                 // open bracket indicates that the argument is a function,
                 // the returning value should be false, i.e. "not a valid cell reference"
                 result = look != '(';
@@ -1339,9 +1379,9 @@ public final class FormulaParser {
             }
         }
 
-        Match('(');
+        match('(');
         ParseNode[] args = Arguments();
-        Match(')');
+        match(')');
 
         return getFunction(name, nameToken, args);
     }
@@ -1448,14 +1488,14 @@ public final class FormulaParser {
     private ParseNode[] Arguments() {
         //average 2 args per function
         List<ParseNode> temp = new ArrayList<>(2);
-        SkipWhite();
+        skipWhite();
         if(look == ')') {
             return ParseNode.EMPTY_ARRAY;
         }
 
         boolean missedPrevArg = true;
         while (true) {
-            SkipWhite();
+            skipWhite();
             if (isArgumentDelimiter(look)) {
                 if (missedPrevArg) {
                     temp.add(new ParseNode(MissingArgPtg.instance));
@@ -1463,13 +1503,13 @@ public final class FormulaParser {
                 if (look == ')') {
                     break;
                 }
-                Match(',');
+                match(',');
                 missedPrevArg = true;
                 continue;
             }
             temp.add(intersectionExpression());
             missedPrevArg = false;
-            SkipWhite();
+            skipWhite();
             if (!isArgumentDelimiter(look)) {
                 throw expected("',' or ')'");
             }
@@ -1483,11 +1523,11 @@ public final class FormulaParser {
     private ParseNode powerFactor() {
         ParseNode result = percentFactor();
         while(true) {
-            SkipWhite();
+            skipWhite();
             if(look != '^') {
                 return result;
             }
-            Match('^');
+            match('^');
             ParseNode other = percentFactor();
             result = new ParseNode(PowerPtg.instance, result, other);
         }
@@ -1496,11 +1536,11 @@ public final class FormulaParser {
     private ParseNode percentFactor() {
         ParseNode result = parseSimpleFactor();
         while(true) {
-            SkipWhite();
+            skipWhite();
             if(look != '%') {
                 return result;
             }
-            Match('%');
+            match('%');
             result = new ParseNode(PercentPtg.instance, result);
         }
     }
@@ -1510,32 +1550,32 @@ public final class FormulaParser {
      * factors (without ^ or % )
      */
     private ParseNode parseSimpleFactor() {
-        SkipWhite();
+        skipWhite();
         switch(look) {
             case '#':
                 return new ParseNode(ErrPtg.valueOf(parseErrorLiteral()));
             case '-':
-                Match('-');
+                match('-');
                 return parseUnary(false);
             case '+':
-                Match('+');
+                match('+');
                 return parseUnary(true);
             case '(':
-                Match('(');
+                match('(');
                 ParseNode inside = unionExpression();
-                Match(')');
+                match(')');
                 return new ParseNode(ParenthesisPtg.instance, inside);
             case '"':
                 return new ParseNode(new StringPtg(parseStringLiteral()));
             case '{':
-                Match('{');
+                match('{');
                 ParseNode arrayNode = parseArray();
-                Match('}');
+                match('}');
                 return arrayNode;
         }
         // named ranges and tables can start with underscore or backslash
         // see https://support.office.com/en-us/article/Define-and-use-names-in-formulas-4d0f13ac-53b7-422e-afd2-abd7ff379c64?ui=en-US&rs=en-US&ad=US#bmsyntax_rules_for_names
-        if (IsAlpha(look) || Character.isDigit(look) || look == '\'' || look == '[' || look == '_' || look == '\\' ) {
+        if (isAlpha(look) || Character.isDigit(look) || look == '\'' || look == '[' || look == '_' || look == '\\' ) {
             return parseRangeExpression();
         }
         if (look == '.') {
@@ -1547,7 +1587,7 @@ public final class FormulaParser {
 
     private ParseNode parseUnary(boolean isPlus) {
 
-        boolean numberFollows = IsDigit(look) || look=='.';
+        boolean numberFollows = isDigit(look) || look=='.';
         ParseNode factor = powerFactor();
 
         if (numberFollows) {
@@ -1585,7 +1625,7 @@ public final class FormulaParser {
             if (look != ';') {
                 throw expected("'}' or ';'");
             }
-            Match(';');
+            match(';');
         }
         int nRows = rowsData.size();
         Object[][] values2d = new Object[nRows][];
@@ -1609,13 +1649,13 @@ public final class FormulaParser {
         List<Object> temp = new ArrayList<>();
         while (true) {
             temp.add(parseArrayItem());
-            SkipWhite();
+            skipWhite();
             switch(look) {
                 case '}':
                 case ';':
                     break;
                 case ',':
-                    Match(',');
+                    match(',');
                     continue;
                 default:
                     throw expected("'}' or ','");
@@ -1630,7 +1670,7 @@ public final class FormulaParser {
     }
 
     private Object parseArrayItem() {
-        SkipWhite();
+        skipWhite();
         switch(look) {
             case '"': return parseStringLiteral();
             case '#': return ErrorConstant.valueOf(parseErrorLiteral());
@@ -1638,8 +1678,8 @@ public final class FormulaParser {
             case 'T': case 't':
                 return parseBooleanLiteral();
             case '-':
-                Match('-');
-                SkipWhite();
+                match('-');
+                skipWhite();
                 return convertArrayNumber(parseNumber(), false);
         }
         // else assume number
@@ -1664,7 +1704,7 @@ public final class FormulaParser {
         } else  if (ptg instanceof NumberPtg) {
             value = ((NumberPtg)ptg).getValue();
         } else {
-            throw new RuntimeException("Unexpected ptg (" + ptg.getClass().getName() + ")");
+            throw new IllegalStateException("Unexpected ptg (" + ptg.getClass().getName() + ")");
         }
         if (!isPositive) {
             value = -value;
@@ -1675,25 +1715,25 @@ public final class FormulaParser {
     private Ptg parseNumber() {
         String number2 = null;
         String exponent = null;
-        String number1 = GetNum();
+        String number1 = nextNum();
 
         if (look == '.') {
-            GetChar();
-            number2 = GetNum();
+            nextChar();
+            number2 = nextNum();
         }
 
         if (look == 'E') {
-            GetChar();
+            nextChar();
 
             String sign = "";
             if (look == '+') {
-                GetChar();
+                nextChar();
             } else if (look == '-') {
-                GetChar();
+                nextChar();
                 sign = "-";
             }
 
-            String number = GetNum();
+            String number = nextNum();
             if (number == null) {
                 throw expected("Integer");
             }
@@ -1709,7 +1749,7 @@ public final class FormulaParser {
 
 
     private int parseErrorLiteral() {
-        Match('#');
+        match('#');
         String part1 = parseUnquotedIdentifier();
         if (part1 == null) {
             throw expected("remainder of error constant literal");
@@ -1720,7 +1760,7 @@ public final class FormulaParser {
             case 'V': {
                 FormulaError fe = FormulaError.VALUE;
                 if(part1.equals(fe.name())) {
-                    Match('!');
+                    match('!');
                     return fe.getCode();
                 }
                 throw expected(fe.getString());
@@ -1728,7 +1768,7 @@ public final class FormulaParser {
             case 'R': {
                 FormulaError fe = FormulaError.REF;
                 if(part1.equals(fe.name())) {
-                    Match('!');
+                    match('!');
                     return fe.getCode();
                 }
                 throw expected(fe.getString());
@@ -1736,9 +1776,9 @@ public final class FormulaParser {
             case 'D': {
                 FormulaError fe = FormulaError.DIV0;
                 if(part1.equals("DIV")) {
-                    Match('/');
-                    Match('0');
-                    Match('!');
+                    match('/');
+                    match('0');
+                    match('!');
                     return fe.getCode();
                 }
                 throw expected(fe.getString());
@@ -1747,26 +1787,26 @@ public final class FormulaParser {
                 FormulaError fe = FormulaError.NAME;
                 if(part1.equals(fe.name())) {
                     // only one that ends in '?'
-                    Match('?');
+                    match('?');
                     return fe.getCode();
                 }
                 fe = FormulaError.NUM;
                 if(part1.equals(fe.name())) {
-                    Match('!');
+                    match('!');
                     return fe.getCode();
                 }
                 fe = FormulaError.NULL;
                 if(part1.equals(fe.name())) {
-                    Match('!');
+                    match('!');
                     return fe.getCode();
                 }
                 fe = FormulaError.NA;
                 if(part1.equals("N")) {
-                    Match('/');
+                    match('/');
                     if(look != 'A' && look != 'a') {
                         throw expected(fe.getString());
                     }
-                    Match(look);
+                    match(look);
                     // Note - no '!' or '?' suffix
                     return fe.getCode();
                 }
@@ -1783,7 +1823,7 @@ public final class FormulaParser {
         StringBuilder sb = new StringBuilder();
         while (Character.isLetterOrDigit(look) || look == '.') {
             sb.appendCodePoint(look);
-            GetChar();
+            nextChar();
         }
         if (sb.length() < 1) {
             return null;
@@ -1837,18 +1877,18 @@ public final class FormulaParser {
 
 
     private String parseStringLiteral() {
-        Match('"');
+        match('"');
 
         StringBuilder token = new StringBuilder();
         while (true) {
             if (look == '"') {
-                GetChar();
+                nextChar();
                 if (look != '"') {
                     break;
                 }
              }
             token.appendCodePoint(look);
-            GetChar();
+            nextChar();
         }
         return token.toString();
     }
@@ -1857,15 +1897,15 @@ public final class FormulaParser {
     private ParseNode  Term() {
         ParseNode result = powerFactor();
         while(true) {
-            SkipWhite();
+            skipWhite();
             Ptg operator;
             switch(look) {
                 case '*':
-                    Match('*');
+                    match('*');
                     operator = MultiplyPtg.instance;
                     break;
                 case '/':
-                    Match('/');
+                    match('/');
                     operator = DividePtg.instance;
                     break;
                 default:
@@ -1880,9 +1920,9 @@ public final class FormulaParser {
         ParseNode result = intersectionExpression();
         boolean hasUnions = false;
         while (true) {
-            SkipWhite();
+            skipWhite();
             if (look == ',') {
-                GetChar();
+                nextChar();
                 hasUnions = true;
                 ParseNode other = intersectionExpression();
                 result = new ParseNode(UnionPtg.instance, result, other);
@@ -1899,7 +1939,7 @@ public final class FormulaParser {
         ParseNode result = comparisonExpression();
         boolean hasIntersections = false;
         while (true) {
-            SkipWhite();
+            skipWhite();
             if (_inIntersection) {
                 int savePointer = _pointer;
 
@@ -1925,7 +1965,7 @@ public final class FormulaParser {
     private ParseNode comparisonExpression() {
         ParseNode result = concatExpression();
         while (true) {
-            SkipWhite();
+            skipWhite();
             switch(look) {
                 case '=':
                 case '>':
@@ -1941,24 +1981,24 @@ public final class FormulaParser {
 
     private Ptg getComparisonToken() {
         if(look == '=') {
-            Match(look);
+            match(look);
             return EqualPtg.instance;
         }
         boolean isGreater = look == '>';
-        Match(look);
+        match(look);
         if(isGreater) {
             if(look == '=') {
-                Match('=');
+                match('=');
                 return GreaterEqualPtg.instance;
             }
             return GreaterThanPtg.instance;
         }
         switch(look) {
             case '=':
-                Match('=');
+                match('=');
                 return LessEqualPtg.instance;
             case '>':
-                Match('>');
+                match('>');
                 return NotEqualPtg.instance;
         }
         return LessThanPtg.instance;
@@ -1968,11 +2008,11 @@ public final class FormulaParser {
     private ParseNode concatExpression() {
         ParseNode result = additiveExpression();
         while (true) {
-            SkipWhite();
+            skipWhite();
             if(look != '&') {
                 break; // finished with concat expression
             }
-            Match('&');
+            match('&');
             ParseNode other = additiveExpression();
             result = new ParseNode(ConcatPtg.instance, result, other);
         }
@@ -1984,15 +2024,15 @@ public final class FormulaParser {
     private ParseNode additiveExpression() {
         ParseNode result = Term();
         while (true) {
-            SkipWhite();
+            skipWhite();
             Ptg operator;
             switch(look) {
                 case '+':
-                    Match('+');
+                    match('+');
                     operator = AddPtg.instance;
                     break;
                 case '-':
-                    Match('-');
+                    match('-');
                     operator = SubtractPtg.instance;
                     break;
                 default:
@@ -2023,7 +2063,7 @@ end;
      */
     private void parse() {
         _pointer=0;
-        GetChar();
+        nextChar();
         _rootNode = unionExpression();
 
         if(_pointer <= _formulaLength) {
