@@ -18,18 +18,18 @@
 package org.apache.poi.ss.formula.function;
 
 import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
-import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.PrintStream;
+import java.io.UncheckedIOException;
 import java.io.UnsupportedEncodingException;
 import java.math.BigInteger;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLConnection;
+import java.nio.charset.StandardCharsets;
+import java.nio.file.Files;
 import java.security.MessageDigest;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -167,8 +167,8 @@ public final class ExcelFileFormatDocFunctionExtractor {
             _groupFunctionNames = new HashSet<>();
         }
 
-        public void addFuntion(int funcIx, boolean hasFootnote, String funcName, int minParams, int maxParams,
-                String returnClass, String paramClasses, String volatileFlagStr) {
+        public void addFunction(int funcIx, boolean hasFootnote, String funcName, int minParams, int maxParams,
+                                String returnClass, String paramClasses, String volatileFlagStr) {
             boolean isVolatile = volatileFlagStr.length() > 0;
 
             Integer funcIxKey = Integer.valueOf(funcIx);
@@ -359,7 +359,7 @@ public final class ExcelFileFormatDocFunctionExtractor {
             String paramClasses = cellData[i + 5];
             String volatileFlagStr = cellData[i + 6];
 
-            _fdc.addFuntion(funcIx, hasFootnote, funcName, minParams, maxParams, returnClass, paramClasses, volatileFlagStr);
+            _fdc.addFunction(funcIx, hasFootnote, funcName, minParams, maxParams, returnClass, paramClasses, volatileFlagStr);
         }
 
         private static int parseInt(String valStr) {
@@ -485,14 +485,14 @@ public final class ExcelFileFormatDocFunctionExtractor {
         }
         OutputStream os;
         try {
-            os = new FileOutputStream(outFile);
-        } catch (FileNotFoundException e) {
-            throw new RuntimeException(e);
+            os = Files.newOutputStream(outFile.toPath());
+        } catch (IOException e) {
+            throw new UncheckedIOException(e);
         }
         os = new SimpleAsciiOutputStream(os);
         PrintStream ps;
         try {
-            ps = new PrintStream(os, true, "UTF-8");
+            ps = new PrintStream(os, true, StandardCharsets.UTF_8.name());
         } catch(UnsupportedEncodingException e) {
             throw new RuntimeException(e);
         }
@@ -558,7 +558,7 @@ public final class ExcelFileFormatDocFunctionExtractor {
 
         byte[]buf = new byte[2048];
         try {
-            InputStream is = new FileInputStream(f);
+            InputStream is = Files.newInputStream(f.toPath());
             while(true) {
                 int bytesRead = is.read(buf);
                 if(bytesRead<1) {
@@ -589,7 +589,7 @@ public final class ExcelFileFormatDocFunctionExtractor {
             InputStream is = conn.getInputStream();
             System.out.println("downloading " + url.toExternalForm());
             result = TempFile.createTempFile("excelfileformat", ".odt");
-            OutputStream os = new FileOutputStream(result);
+            OutputStream os = Files.newOutputStream(result.toPath());
             while(true) {
                 int bytesRead = is.read(buf);
                 if(bytesRead<1) {
@@ -600,7 +600,7 @@ public final class ExcelFileFormatDocFunctionExtractor {
             is.close();
             os.close();
         } catch (IOException e) {
-            throw new RuntimeException(e);
+            throw new UncheckedIOException(e);
         }
         System.out.println("file downloaded ok");
         return result;
