@@ -143,6 +143,74 @@ final class TestIOUtils {
                 IOUtils.toByteArray(ByteBuffer.wrap(new byte[]{1, 2, 3, 4, 5, 6, 7}), 3));
     }
 
+    @Test
+    void testToByteArrayMaxLength() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertArrayEquals(array, IOUtils.toByteArrayWithMaxLength(is, 7));
+        }
+    }
+
+    @Test
+    void testToByteArrayMaxLengthWithByteArrayInitLenShort() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        IOUtils.setMaxByteArrayInitSize(2);
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertEquals(2, IOUtils.getMaxByteArrayInitSize());
+            assertArrayEquals(array, IOUtils.toByteArrayWithMaxLength(is, 7));
+        } finally {
+            IOUtils.setMaxByteArrayInitSize(-1);
+        }
+    }
+
+    @Test
+    void testToByteArrayMaxLengthWithByteArrayInitLenLong() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        IOUtils.setMaxByteArrayInitSize(8192);
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertEquals(8192, IOUtils.getMaxByteArrayInitSize());
+            assertArrayEquals(array, IOUtils.toByteArrayWithMaxLength(is, 7));
+        } finally {
+            IOUtils.setMaxByteArrayInitSize(-1);
+        }
+    }
+
+    @Test
+    void testToByteArrayMaxLengthLongerThanArray() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertArrayEquals(array, IOUtils.toByteArrayWithMaxLength(is, 8));
+        }
+    }
+
+    @Test
+    void testToByteArrayMaxLengthShorterThanArray() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertThrows(RecordFormatException.class, () -> IOUtils.toByteArrayWithMaxLength(is, 3));
+        }
+    }
+
+    @Test
+    void testToByteArrayMaxLengthShorterThanArrayWithByteArrayOverride() throws IOException {
+        final byte[] array = new byte[]{1, 2, 3, 4, 5, 6, 7};
+        IOUtils.setByteArrayMaxOverride(30 * 1024 * 1024);
+        try (ByteArrayInputStream is = new ByteArrayInputStream(array)) {
+            assertArrayEquals(array, IOUtils.toByteArrayWithMaxLength(is, 3));
+        } finally {
+            IOUtils.setByteArrayMaxOverride(-1);
+        }
+    }
+
+    @Test
+    void testCalculateByteArrayInitLength() throws IOException {
+        assertEquals(4096, IOUtils.calculateByteArrayInitLength(false, 6000, 10000));
+        assertEquals(3000, IOUtils.calculateByteArrayInitLength(false, 3000, 10000));
+        assertEquals(3000, IOUtils.calculateByteArrayInitLength(false, 10000, 3000));
+        assertEquals(10000, IOUtils.calculateByteArrayInitLength(true, 10000, 12000));
+        assertEquals(10000, IOUtils.calculateByteArrayInitLength(true, 12000, 10000));
+    }
+
     @Test
     void testSkipFully() throws IOException {
         try (InputStream is =  new FileInputStream(TMP)) {
@@ -161,7 +229,7 @@ final class TestIOUtils {
 
     @Test
     void testSkipFullyByteArray() throws IOException {
-        UnsynchronizedByteArrayOutputStream bos = new UnsynchronizedByteArrayOutputStream();
+        UnsynchronizedByteArrayOutputStream bos = UnsynchronizedByteArrayOutputStream.builder().get();
         try (InputStream is = new FileInputStream(TMP)) {
             assertEquals(LENGTH, IOUtils.copy(is, bos));
             long skipped = IOUtils.skipFully(bos.toInputStream(), 20000L);
@@ -171,7 +239,7 @@ final class TestIOUtils {
 
     @Test
     void testSkipFullyByteArrayGtIntMax() throws IOException {
-        UnsynchronizedByteArrayOutputStream bos = new UnsynchronizedByteArrayOutputStream();
+        UnsynchronizedByteArrayOutputStream bos = UnsynchronizedByteArrayOutputStream.builder().get();
         try (InputStream is = new FileInputStream(TMP)) {
             assertEquals(LENGTH, IOUtils.copy(is, bos));
             long skipped = IOUtils.skipFully(bos.toInputStream(), Integer.MAX_VALUE + 20000L);
@@ -254,7 +322,8 @@ final class TestIOUtils {
             len = IOUtils.toByteArray(is, 90, 100).length;
             assertEquals(90, len);
             len = IOUtils.toByteArray(is, Integer.MAX_VALUE, Integer.MAX_VALUE).length;
-            assertTrue(len > 300-2*90);
+            assertTrue(len >= 300-2*90,
+                    "Had: " + len + " when reading file " + TMP + " with size " + TMP.length());
         }
     }
 
